[evolvis-commits] r12452: Renamed soapclient class to gfsoapclient for compatibility with PHP5.

mirabilos at evolvis.org mirabilos at evolvis.org
Mon Feb 28 01:39:15 CET 2011


Author: mirabilos
Date: 2011-02-28 01:39:15 +0100 (Mon, 28 Feb 2011)
New Revision: 12452

Modified:
   trunk/gforge_base/evolvisforge-5.1/gforge/ChangeLog
   trunk/gforge_base/evolvisforge-5.1/gforge/www/soap/nusoap.php
Log:
Renamed soapclient class to gfsoapclient for compatibility with PHP5.

Modified: trunk/gforge_base/evolvisforge-5.1/gforge/ChangeLog
===================================================================
--- trunk/gforge_base/evolvisforge-5.1/gforge/ChangeLog	2011-02-28 00:39:13 UTC (rev 12451)
+++ trunk/gforge_base/evolvisforge-5.1/gforge/ChangeLog	2011-02-28 00:39:15 UTC (rev 12452)
@@ -1,3 +1,8 @@
+2008-05-05  Roland Mas  <lolando at debian.org>
+
+	* www/soap/nusoap.php: Renamed soapclient class to gfsoapclient,
+	for compatibility with PHP5.
+
 2008-04-24  Roland Mas  <lolando at debian.org>
 
 	* etc/local.d/10database.header: Read database authentication info

Modified: trunk/gforge_base/evolvisforge-5.1/gforge/www/soap/nusoap.php
===================================================================
--- trunk/gforge_base/evolvisforge-5.1/gforge/www/soap/nusoap.php	2011-02-28 00:39:13 UTC (rev 12451)
+++ trunk/gforge_base/evolvisforge-5.1/gforge/www/soap/nusoap.php	2011-02-28 00:39:15 UTC (rev 12452)
@@ -5640,24 +5640,24 @@
 
 /**
  *
  * soapclient higher level class for easy usage.
  *
  * usage:
  *
  * // instantiate client with server info
- * $soapclient = new soapclient( string path [ ,boolean wsdl] );
+ * $gfsoapclient = new gfsoapclient( string path [ ,boolean wsdl] );
  *
  * // call method, get results
- * echo $soapclient->call( string methodname [ ,array parameters] );
+ * echo $gfsoapclient->call( string methodname [ ,array parameters] );
  *
  * // bye bye client
- * unset($soapclient);
+ * unset($gfsoapclient);
  *
  * @author   Dietrich Ayala <dietrich at ganx4.com>
  * @version  $Id$
  * @access   public
  */
-class soapclient extends nusoap_base  {
+class gfsoapclient extends nusoap_base  {
 
 	var $username = '';
 	var $password = '';
@@ -5710,7 +5710,7 @@
 	 * @param	integer $response_timeout set the response timeout
 	 * @access   public
 	 */
-	function soapclient($endpoint,$wsdl = false,$proxyhost = false,$proxyport = false,$proxyusername = false, $proxypassword = false, $timeout = 0, $response_timeout = 30){
+	function gfsoapclient($endpoint,$wsdl = false,$proxyhost = false,$proxyport = false,$proxyusername = false, $proxypassword = false, $timeout = 0, $response_timeout = 30){
 		$this->endpoint = $endpoint;
 		$this->proxyhost = $proxyhost;
 		$this->proxyport = $proxyport;
@@ -6209,7 +6209,7 @@
 			}
 		}
 		$r = rand();
-		$evalStr = 'class soap_proxy_'.$r.' extends soapclient {
+		$evalStr = 'class soap_proxy_'.$r.' extends gfsoapclient {
 				'.$evalStr.'
 			}';
 		//print "proxy class:<pre>$evalStr</pre>";
@@ -5640,24 +5640,24 @@
 /**
  *
- * soapclient higher level class for easy usage.
+ * gfsoapclient higher level class for easy usage.
  *
  * usage:



More information about the evolvis-commits mailing list